======================
:code:`Trakt['shows']`
======================

.. automodule:: trakt.interfaces.shows

  .. autoclass:: ShowsInterface
    :members: episode, get, last_episode, next_episode, progress, progress_collection, progress_watched, season, seasons, trending
    :undoc-members:
